@@ -65,11 +65,18 @@
 #define RENAME_SESSION "Rename Session"
 #define FULLSCREEN "Fullscreen"
 
+#define HANDLE_HISTORY "Handle history"
+
 /* Some defaults for QTerminal application */
 
 #define DEFAULT_WIDTH                  800
 #define DEFAULT_HEIGHT                 600
+#ifdef Q_OS_MACOS
+// Qt does not support fontconfig on macOS, so we need to use a "real" font name.
+#define DEFAULT_FONT                   "Menlo"
+#else
 #define DEFAULT_FONT                   "Monospace"
+#endif
 
 // ACTIONS
 #define CLEAR_TERMINAL_SHORTCUT        "Ctrl+Shift+X"
@@ -83,10 +90,11 @@
 #define SUB_LEFT_SHORTCUT	       "Alt+Left"
 #define SUB_RIGHT_SHORTCUT	       "Alt+Right"
 
-#ifdef Q_WS_MAC
+#ifdef Q_OS_MACOS
 // It's tricky - Ctrl is "command" key on mac's keyboards
 #define COPY_SELECTION_SHORTCUT      "Ctrl+C"
 #define PASTE_CLIPBOARD_SHORTCUT      "Ctrl+V"
+#define PASTE_SELECTION_SHORTCUT      "Shift+Ins"
 #define FIND_SHORTCUT                "Ctrl+F"
 #define NEW_WINDOW_SHORTCUT          "Ctrl+N"
 #define ADD_TAB_SHORTCUT               "Ctrl+T"
