@@ -19,10 +19,11 @@
 #include <QApplication>
 #include <QtGlobal>
 
-#include <assert.h>
-#include <stdio.h>
+#include <cassert>
+#include <cstdio>
 #include <getopt.h>
-#include <stdlib.h>
+#include <cstdlib>
+#include <unistd.h>
 #ifdef HAVE_QDBUS
     #include <QtDBus/QtDBus>
     #include <unistd.h>
@@ -39,18 +40,18 @@
 const char* const short_options = "vhw:e:dp:";
 
 const struct option long_options[] = {
-    {"version", 0, NULL, 'v'},
-    {"help",    0, NULL, 'h'},
-    {"workdir", 1, NULL, 'w'},
-    {"execute", 1, NULL, 'e'},
-    {"drop",    0, NULL, 'd'},
-    {"profile", 1, NULL, 'p'},
-    {NULL,      0, NULL,  0}
+    {"version", 0, nullptr, 'v'},
+    {"help",    0, nullptr, 'h'},
+    {"workdir", 1, nullptr, 'w'},
+    {"execute", 1, nullptr, 'e'},
+    {"drop",    0, nullptr, 'd'},
+    {"profile", 1, nullptr, 'p'},
+    {nullptr,   0, nullptr,  0}
 };
 
-QTerminalApp * QTerminalApp::m_instance = NULL;
+QTerminalApp * QTerminalApp::m_instance = nullptr;
 
-void print_usage_and_exit(int code)
+[[ noreturn ]] void print_usage_and_exit(int code)
 {
     printf("QTerminal %s\n", QTERMINAL_VERSION);
     puts("Usage: qterminal [OPTION]...\n");
@@ -65,7 +66,7 @@ void print_usage_and_exit(int code)
     exit(code);
 }
 
-void print_version_and_exit(int code=0)
+[[ noreturn ]] void print_version_and_exit(int code=0)
 {
     printf("%s\n", QTERMINAL_VERSION);
     exit(code);
@@ -76,7 +77,7 @@ void parse_args(int argc, char* argv[], QString& workdir, QString & shell_comman
     int next_option;
     dropMode = false;
     do{
-        next_option = getopt_long(argc, argv, short_options, long_options, NULL);
+        next_option = getopt_long(argc, argv, short_options, long_options, nullptr);
         switch(next_option)
         {
             case 'h':
@@ -114,6 +115,20 @@ void parse_args(int argc, char* argv[], QString& workdir, QString & shell_comman
 
 int main(int argc, char *argv[])
 {
+    if (!qEnvironmentVariableIsEmpty("XPC_SERVICE_NAME")) {
+        // On macOS, if qterminal.app is spawned by launchd (e.g., from Finder
+        // or use `open qterminal.app`, $PWD is set to /. Workaround that by
+        // go to $HOME first.
+        if (chdir(QDir::homePath().toLatin1().data())) {
+            qDebug() << "Failed to chdir to $HOME" << QDir::homePath() << strerror(errno);
+        }
+
+        // also initializes $LANG
+        QString systemLocaleName(QLocale().name());
+        systemLocaleName.append(QLatin1String(".UTF-8"));
+        qputenv("LANG", systemLocaleName.toLatin1());
+    }
+
     QApplication::setApplicationName(QStringLiteral("qterminal"));
     QApplication::setApplicationVersion(QStringLiteral(QTERMINAL_VERSION));
     QApplication::setOrganizationDomain(QStringLiteral("qterminal.org"));
@@ -161,15 +176,27 @@ int main(int argc, char *argv[])
         QIcon::setThemeName(QStringLiteral("QTerminal"));
 
     // translations
-    QString fname = QString::fromLatin1("qterminal_%1.qm").arg(QLocale::system().name().left(5));
+
+    // install the translations built-into Qt itself
+    QTranslator qtTranslator;
+    qtTranslator.load(QStringLiteral("qt_") + QLocale::system().name(), QLibraryInfo::location(QLibraryInfo::TranslationsPath));
+    app->installTranslator(&qtTranslator);
+
     QTranslator translator;
+    QString fname = QString::fromLatin1("qterminal_%1.qm").arg(QLocale::system().name().left(5));
 #ifdef TRANSLATIONS_DIR
-    qDebug() << "TRANSLATIONS_DIR: Loading translation file" << fname << "from dir" << TRANSLATIONS_DIR;
-    qDebug() << "load success:" << translator.load(fname, QString::fromUtf8(TRANSLATIONS_DIR), QStringLiteral("_"));
+    //qDebug() << "TRANSLATIONS_DIR: Loading translation file" << fname << "from dir" << TRANSLATIONS_DIR;
+    /*qDebug() << "load success:" <<*/ translator.load(fname, QString::fromUtf8(TRANSLATIONS_DIR), QStringLiteral("_"));
 #endif
 #ifdef APPLE_BUNDLE
-    qDebug() << "APPLE_BUNDLE: Loading translator file" << fname << "from dir" << QApplication::applicationDirPath()+"../translations";
-    qDebug() << "load success:" << translator.load(fname, QApplication::applicationDirPath()+"../translations", "_");
+    QDir translations_dir = QDir(QApplication::applicationDirPath());
+    translations_dir.cdUp();
+    if (translations_dir.cd(QStringLiteral("Resources/translations"))) {
+        //qDebug() << "APPLE_BUNDLE: Loading translator file" << fname << "from dir" << translations_dir.path();
+        /*qDebug() << "load success:" <<*/ translator.load(fname, translations_dir.path(), QStringLiteral("_"));
+    } /*else {
+        qWarning() << "Unable to find \"Resources/translations\" dir in" << translations_dir.path();
+    }*/
 #endif
     app->installTranslator(&translator);
 
@@ -185,10 +212,10 @@ int main(int argc, char *argv[])
 
 MainWindow *QTerminalApp::newWindow(bool dropMode, TerminalConfig &cfg)
 {
-    MainWindow *window = NULL;
+    MainWindow *window = nullptr;
     if (dropMode)
     {
-        QWidget *hiddenPreviewParent = new QWidget(0, Qt::Tool);
+        QWidget *hiddenPreviewParent = new QWidget(nullptr, Qt::Tool);
         window = new MainWindow(cfg, dropMode, hiddenPreviewParent);
         if (Properties::Instance()->dropShowOnStart)
             window->show();
@@ -205,13 +232,13 @@ MainWindow *QTerminalApp::newWindow(bool dropMode, TerminalConfig &cfg)
 
 QTerminalApp *QTerminalApp::Instance()
 {
-    assert(m_instance != NULL);
+    assert(m_instance != nullptr);
     return m_instance;
 }
 
 QTerminalApp *QTerminalApp::Instance(int &argc, char **argv)
 {
-    assert(m_instance == NULL);
+    assert(m_instance == nullptr);
     m_instance = new QTerminalApp(argc, argv);
     return m_instance;
 }
@@ -233,7 +260,7 @@ void QTerminalApp::setWorkingDirectory(const QString &wd)
 
 void QTerminalApp::cleanup() {
     delete m_instance;
-    m_instance = NULL;
+    m_instance = nullptr;
 }
 
 
@@ -286,14 +313,14 @@ QDBusObjectPath QTerminalApp::newWindow(const QHash<QString,QVariant> &termArgs)
 {
     TerminalConfig cfg = TerminalConfig::fromDbus(termArgs);
     MainWindow *wnd = newWindow(false, cfg);
-    assert(wnd != NULL);
+    assert(wnd != nullptr);
     return wnd->getDbusPath();
 }
 
 QDBusObjectPath QTerminalApp::getActiveWindow()
 {
     QWidget *aw = activeWindow();
-    if (aw == NULL)
+    if (aw == nullptr)
         return QDBusObjectPath("/");
     return qobject_cast<MainWindow*>(aw)->getDbusPath();
 }
