@@ -67,12 +67,14 @@ class Properties
         int appTransparency;
         int termTransparency;
         QString backgroundImage;
+        int backgroundMode;
 
         int scrollBarPos;
         int tabsPos;
         int keyboardCursorShape;
         bool hideTabBarWithOneTab;
         int m_motionAfterPaste;
+        bool m_disableBracketedPasteMode;
 
         bool fixedTabWidth;
         int fixedTabWidthValue;
