@@ -138,6 +138,8 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
 
     backgroundImageLineEdit->setText(Properties::Instance()->backgroundImage);
 
+    backgroundModecomboBox->setCurrentIndex(Properties::Instance()->backgroundMode);
+
     emulationComboBox->addItems(emulations);
     int eix = emulationComboBox->findText(Properties::Instance()->emulation);
     emulationComboBox->setCurrentIndex(eix != -1 ? eix : 0 );
@@ -187,10 +189,12 @@ PropertiesDialog::PropertiesDialog(QWidget *parent)
     /* actions by motion after paste */
 
     QStringList motionAfter;
-    motionAfter << tr("No move") << tr("Move start") << tr("Move end");
+    motionAfter << tr("No move") << tr("Scrolling to top") << tr("Scrolling to bottom");
     motionAfterPasting_comboBox->addItems(motionAfter);
     motionAfterPasting_comboBox->setCurrentIndex(Properties::Instance()->m_motionAfterPaste);
 
+    disableBracketedPasteModeCheckBox->setChecked(Properties::Instance()->m_disableBracketedPasteMode);
+
     // Setting windows style actions
     styleComboBox->addItem(tr("System Default"));
     styleComboBox->addItems(QStyleFactory::keys());
@@ -303,6 +307,7 @@ void PropertiesDialog::apply()
     Properties::Instance()->highlightCurrentTerminal = highlightCurrentCheckBox->isChecked();
     Properties::Instance()->showTerminalSizeHint = showTerminalSizeHintCheckBox->isChecked();
     Properties::Instance()->backgroundImage = backgroundImageLineEdit->text();
+    Properties::Instance()->backgroundMode = qBound(0, backgroundModecomboBox->currentIndex(), 4);
 
     Properties::Instance()->askOnExit = askOnExitCheckBox->isChecked();
 
@@ -330,6 +335,7 @@ void PropertiesDialog::apply()
     Properties::Instance()->menuVisible = showMenuCheckBox->isChecked();
     Properties::Instance()->borderless = borderlessCheckBox->isChecked();
     Properties::Instance()->m_motionAfterPaste = motionAfterPasting_comboBox->currentIndex();
+    Properties::Instance()->m_disableBracketedPasteMode = disableBracketedPasteModeCheckBox->isChecked();
 
     Properties::Instance()->historyLimited = historyLimited->isChecked();
     Properties::Instance()->historyLimitedTo = historyLimitedTo->value();
@@ -381,7 +387,7 @@ void PropertiesDialog::chooseBackgroundImageButton_clicked()
 {
     QString filename = QFileDialog::getOpenFileName(
                             this, tr("Choose a background image"),
-                            QString(), tr("Images (*.bmp *.png *.xpm *.jpg)"));
+                            QString(), tr("Images (*.bmp *.jpg *.png *.svg *.xpm)"));
     if (!filename.isNull())
         backgroundImageLineEdit->setText(filename);
 }
