@@ -88,7 +88,9 @@ int TabWidget::addNewTab(TerminalConfig config)
     connect(console, &TermWidgetHolder::termTitleChanged, this, &TabWidget::onTermTitleChanged);
     connect(this, &QTabWidget::currentChanged, this, &TabWidget::currentTitleChanged);
 
-    int index = addTab(console, label);
+    const int newIndex = (Properties::Instance()->m_openNewTabRightToActiveTab ? currentIndex() + 1 : count());
+    const int index = insertTab(newIndex, console, label);
+
     console->setProperty(TAB_CUSTOM_NAME_PROPERTY, false);
     updateTabIndices();
     switchTab(index);
@@ -171,7 +173,7 @@ void TabWidget::updateTabIndices()
         widget(i)->setProperty(TAB_INDEX_PROPERTY, i);
 }
 
-void TabWidget::onTermTitleChanged(QString title, QString icon)
+void TabWidget::onTermTitleChanged(const QString& title, const QString& icon)
 {
     TermWidgetHolder * console = qobject_cast<TermWidgetHolder*>(sender());
     const bool custom_name = console->property(TAB_CUSTOM_NAME_PROPERTY).toBool();
@@ -258,7 +260,7 @@ bool TabWidget::eventFilter(QObject *obj, QEvent *event)
 {
     QMouseEvent *e = reinterpret_cast<QMouseEvent*>(event);
     if (e->button() == Qt::MidButton) {
-        if (event->type() == QEvent::MouseButtonRelease) {
+        if (event->type() == QEvent::MouseButtonRelease && Properties::Instance()->closeTabOnMiddleClick) {
             // close the tab on middle clicking
             int index = tabBar()->tabAt(e->pos());
             if (index > -1){
