@@ -59,7 +59,11 @@ TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
     if (!shell.isEmpty())
     {
         //qDebug() << "Shell program:" << shell;
+#if (QT_VERSION >= QT_VERSION_CHECK(5,15,0))
+        QStringList parts = shell.split(QRegExp(QStringLiteral("\\s+")), Qt::SkipEmptyParts);
+#else
         QStringList parts = shell.split(QRegExp(QStringLiteral("\\s+")), QString::SkipEmptyParts);
+#endif
         //qDebug() << parts;
         setShellProgram(parts.at(0));
         parts.removeAt(0);
@@ -68,6 +72,7 @@ TermWidgetImpl::TermWidgetImpl(TerminalConfig &cfg, QWidget * parent)
     }
 
     setMotionAfterPasting(Properties::Instance()->m_motionAfterPaste);
+    disableBracketedPasteMode(Properties::Instance()->m_disableBracketedPasteMode);
 
     setContextMenuPolicy(Qt::CustomContextMenu);
     connect(this, &QWidget::customContextMenuRequested,
@@ -84,6 +89,9 @@ void TermWidgetImpl::propertiesChanged()
     setColorScheme(Properties::Instance()->colorScheme);
     setTerminalFont(Properties::Instance()->font);
     setMotionAfterPasting(Properties::Instance()->m_motionAfterPaste);
+    disableBracketedPasteMode(Properties::Instance()->m_disableBracketedPasteMode);
+    setConfirmMultilinePaste(Properties::Instance()->confirmMultilinePaste);
+    setTrimPastedTrailingNewlines(Properties::Instance()->trimPastedTrailingNewlines);
     setTerminalSizeHint(Properties::Instance()->showTerminalSizeHint);
 
     if (Properties::Instance()->historyLimited)
@@ -99,6 +107,7 @@ void TermWidgetImpl::propertiesChanged()
     setKeyBindings(Properties::Instance()->emulation);
     setTerminalOpacity(1.0 - Properties::Instance()->termTransparency/100.0);
     setTerminalBackgroundImage(Properties::Instance()->backgroundImage);
+    setTerminalBackgroundMode(Properties::Instance()->backgroundMode);
     setBidiEnabled(Properties::Instance()->enabledBidiSupport);
     setDrawLineChars(!Properties::Instance()->useFontBoxDrawingChars);
     setBoldIntense(Properties::Instance()->boldIntense);
@@ -198,78 +207,6 @@ void TermWidgetImpl::activateUrl(const QUrl & url, bool fromContextMenu) {
     }
 }
 
-void TermWidgetImpl::pasteSelection()
-{
-    paste(QClipboard::Selection);
-}
-
-void TermWidgetImpl::pasteClipboard()
-{
-    paste(QClipboard::Clipboard);
-}
-
-void TermWidgetImpl::paste(QClipboard::Mode mode)
-{
-    // Paste Clipboard by simulating keypress events
-    QString text = QApplication::clipboard()->text(mode);
-    if ( ! text.isEmpty() )
-    {
-        text.replace(QLatin1String("\r\n"), QLatin1String("\n"));
-        text.replace(QLatin1Char('\n'), QLatin1Char('\r'));
-        QString trimmedTrailingNl(text);
-        trimmedTrailingNl.replace(QRegExp(QStringLiteral("\\r+$")), QString());
-        bool isMultiline = trimmedTrailingNl.contains(QLatin1Char('\r'));
-        if (!isMultiline && Properties::Instance()->trimPastedTrailingNewlines)
-        {
-            text = trimmedTrailingNl;
-        }
-        if (Properties::Instance()->confirmMultilinePaste)
-        {
-            if (text.contains(QLatin1Char('\r')) && Properties::Instance()->confirmMultilinePaste)
-            {
-                QMessageBox confirmation(this);
-                confirmation.setWindowTitle(tr("Paste multiline text"));
-                confirmation.setText(tr("Are you sure you want to paste this text?"));
-                confirmation.setDetailedText(text);
-                confirmation.setStandardButtons(QMessageBox::Yes | QMessageBox::No);
-                // Click "Show details..." to show those by default
-                const auto buttons = confirmation.buttons();
-                for( QAbstractButton * btn : buttons )
-                {
-                    if (confirmation.buttonRole(btn) == QMessageBox::ActionRole && btn->text() == QMessageBox::tr("Show Details..."))
-                    {
-                        Q_EMIT btn->clicked();
-                        break;
-                    }
-                }
-                confirmation.setDefaultButton(QMessageBox::Yes);
-                confirmation.exec();
-                if (confirmation.standardButton(confirmation.clickedButton()) != QMessageBox::Yes)
-                {
-                    return;
-                }
-            }
-        }
-
-        bracketText(text);
-        sendText(text);
-    }
-}
-
-bool TermWidget::eventFilter(QObject * /*obj*/, QEvent * ev)
-{
-    if (ev->type() == QEvent::MouseButtonPress)
-    {
-        QMouseEvent *mev = (QMouseEvent *)ev;
-        if ( mev->button() == Qt::MidButton )
-        {
-            impl()->pasteSelection();
-            return true;
-        }
-    }
-    return false;
-}
-
 TermWidget::TermWidget(TerminalConfig &cfg, QWidget * parent)
     : QWidget(parent),
       DBusAddressable(QStringLiteral("/terminals"))
@@ -287,14 +224,6 @@ TermWidget::TermWidget(TerminalConfig &cfg, QWidget * parent)
 
     m_layout->addWidget(m_term);
     const auto objs = m_term->children();
-    for (QObject *o : objs)
-    {
-        // Find TerminalDisplay
-        if (!o->isWidgetType() || qobject_cast<QWidget*>(o)->isHidden())
-            continue;
-        o->installEventFilter(this);
-    }
-
 
     propertiesChanged();
 
