@@ -51,8 +51,8 @@ class TermWidgetHolder : public QWidget
     Q_OBJECT
 
     public:
-        TermWidgetHolder(TerminalConfig &cfg, QWidget * parent=0);
-        ~TermWidgetHolder();
+        TermWidgetHolder(TerminalConfig &cfg, QWidget * parent=nullptr);
+        ~TermWidgetHolder() override;
 
         void propertiesChanged();
         void setInitialFocus();
